@@ -23,6 +23,7 @@
 #define __GPM_GRAPH_H__
 
 #include <gtk/gtk.h>
+#include "gpm-info-data.h"
 
 G_BEGIN_DECLS
 
@@ -41,34 +42,39 @@ typedef enum {
 	GPM_GRAPH_COLOUR_DEFAULT,
 	GPM_GRAPH_COLOUR_WHITE,
 	GPM_GRAPH_COLOUR_BLACK,
-	GPM_GRAPH_COLOUR_BLUE,
 	GPM_GRAPH_COLOUR_RED,
-	GPM_GRAPH_COLOUR_PURPLE,
+	GPM_GRAPH_COLOUR_BLUE,
+	GPM_GRAPH_COLOUR_GREEN,
+	GPM_GRAPH_COLOUR_MAGENTA,
 	GPM_GRAPH_COLOUR_YELLOW,
+	GPM_GRAPH_COLOUR_CYAN,
+	GPM_GRAPH_COLOUR_GREY,
 	GPM_GRAPH_COLOUR_DARK_BLUE,
 	GPM_GRAPH_COLOUR_DARK_RED,
-	GPM_GRAPH_COLOUR_DARK_PURPLE,
+	GPM_GRAPH_COLOUR_DARK_MAGENTA,
 	GPM_GRAPH_COLOUR_DARK_YELLOW,
+	GPM_GRAPH_COLOUR_DARK_GREEN,
+	GPM_GRAPH_COLOUR_DARK_CYAN,
+	GPM_GRAPH_COLOUR_DARK_GREY,
 	GPM_GRAPH_COLOUR_LAST
 } GpmGraphColour;
 
 typedef enum {
-	GPM_GRAPH_EVENT_AC_REMOVED,
-	GPM_GRAPH_EVENT_LOW_POWER,
+	GPM_GRAPH_EVENT_ON_AC,
+	GPM_GRAPH_EVENT_ON_BATTERY,
 	GPM_GRAPH_EVENT_SCREEN_DIM,
+	GPM_GRAPH_EVENT_SCREEN_RESUME,
 	GPM_GRAPH_EVENT_DPMS_OFF,
+	GPM_GRAPH_EVENT_DPMS_ON,
 	GPM_GRAPH_EVENT_SUSPEND,
 	GPM_GRAPH_EVENT_HIBERNATE,
+	GPM_GRAPH_EVENT_RESUME,
+	GPM_GRAPH_EVENT_LID_CLOSED,
+	GPM_GRAPH_EVENT_LID_OPENED,
+	GPM_GRAPH_EVENT_NOTIFICATION,
 	GPM_GRAPH_EVENT_LAST
 } GpmGraphEvent;
 
-typedef struct {
-	int		x;
-	int		y;
-	GpmGraphColour	colour;
-	gboolean	info_point;
-} GpmDataPoint;
-
 typedef enum {
 	GPM_GRAPH_TYPE_PERCENTAGE,
 	GPM_GRAPH_TYPE_TIME,
@@ -78,7 +84,7 @@ typedef enum {
 
 struct GpmGraph
 {
-	GtkDrawingArea		 parent;
+	GtkDrawingArea	 parent;
 	GpmGraphPrivate	*priv;
 };
 
@@ -87,16 +93,25 @@ struct GpmGraphClass
 	GtkDrawingAreaClass parent_class;
 };
 
-GType		 gpm_graph_get_type	(void);
-GtkWidget	*gpm_graph_new		(void);
+GType		 gpm_graph_get_type			(void);
+GtkWidget	*gpm_graph_new				(void);
 
-void		 gpm_graph_set_invert_x		(GpmGraph *graph, gboolean inv);
-void		 gpm_graph_set_invert_y		(GpmGraph *graph, gboolean inv);
-void		 gpm_graph_set_data		(GpmGraph *graph, GList *list);
-void		 gpm_graph_set_axis_x		(GpmGraph *graph, GpmGraphAxisType axis);
-void		 gpm_graph_set_axis_y		(GpmGraph *graph, GpmGraphAxisType axis);
-const char *	 gpm_graph_event_description	(GpmGraphEvent    event,
-						 GpmGraphColour  *colour);
+void		 gpm_graph_set_invert_x			(GpmGraph	*graph,
+							 gboolean	 inv);
+void		 gpm_graph_enable_legend		(GpmGraph	*graph,
+							 gboolean	 enable);
+void		 gpm_graph_set_invert_y			(GpmGraph	*graph,
+							 gboolean	 inv);
+void		 gpm_graph_set_data			(GpmGraph	*graph,
+							 GpmInfoData	*data);
+void		 gpm_graph_set_events			(GpmGraph	*graph,
+							 GpmInfoData	*data);
+void		 gpm_graph_set_axis_x			(GpmGraph	*graph,
+							 GpmGraphAxisType axis);
+void		 gpm_graph_set_axis_y			(GpmGraph	*graph,
+							 GpmGraphAxisType axis);
+const char *	 gpm_graph_event_description		(GpmGraphEvent	 event);
+GpmGraphColour	 gpm_graph_event_colour			(GpmGraphEvent	 event);
 
 G_END_DECLS
 
